@@ -3,6 +3,7 @@ use strict;
 use warnings;
 
 use Carp ();
+use Exporter::Tiny ();
 use Tie::Array ();
 use Tie::Hash ();
 use Tie::Scalar ();
@@ -13,10 +14,9 @@ BEGIN
 {
 	package Type::Tie;
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.004';
-	
-	use base "Exporter::TypeTiny";
-	our @EXPORT = qw(ttie);
+	our $VERSION   = '0.005';
+	our @ISA       = qw( Exporter::Tiny );
+	our @EXPORT    = qw( ttie );
 	
 	sub ttie (\[$@%]$;@)#>&%*/&<%\$[]^!@;@)
 	{
@@ -45,7 +45,7 @@ BEGIN
 {
 	package Type::Tie::BASE;
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.004';
+	our $VERSION   = '0.005';
 	
 	use Hash::FieldHash qw(fieldhash);
 	fieldhash(my %TYPE);
@@ -122,9 +122,8 @@ BEGIN
 {
 	package Type::Tie::ARRAY;
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.004';
-	
-	use base qw( Tie::StdArray Type::Tie::BASE );
+	our $VERSION   = '0.005';
+	our @ISA       = qw( Tie::StdArray Type::Tie::BASE );
 	
 	sub TIEARRAY
 	{
@@ -164,9 +163,8 @@ BEGIN
 {
 	package Type::Tie::HASH;
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.004';
-	
-	use base qw( Tie::StdHash Type::Tie::BASE );
+	our $VERSION   = '0.005';
+	our @ISA       = qw( Tie::StdHash Type::Tie::BASE );
 	
 	sub TIEHASH
 	{
@@ -187,9 +185,8 @@ BEGIN
 {
 	package Type::Tie::SCALAR;
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.004';
-	
-	use base qw( Tie::StdScalar Type::Tie::BASE );
+	our $VERSION   = '0.005';
+	our @ISA       = qw( Tie::StdScalar Type::Tie::BASE );
 	
 	sub TIESCALAR
 	{
